==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/libs/utils/idatabasedumper.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2012 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *   Main developers : Eric MAEKER, <eric.maeker@gmail.com>                *
 *   Contributors :                                                        *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef IDATABASEDUMPER_H
#define IDATABASEDUMPER_H

#include <QObject>

/**
 * \file idatabasedumper.h
 * \author Eric MAEKER <eric.maeker@gmail.com>
 * \version 0.6.0
 * \date 27 Sept 2011
*/

namespace Utils {

class IDatabaseDumper : public QObject
{
    Q_OBJECT
public:
    IDatabaseDumper(QObject *parent = 0) : QObject(parent) {}
    ~IDatabaseDumper() {}

    virtual bool dumpDatabaseToFile(const QString &file, bool zip = true) = 0;
    virtual bool restoreDatabaseFromFile(const QString &file) = 0;

    virtual bool errorEncountered() const = 0;

Q_SIGNALS:
    void processStarted();
    void processDone();
    void error(const QString &error);
    void message(const QString &message);
};

}  // End namespace Utils

#endif // IDATABASEDUMPER_H

==> freemedforms-project_0.9.0.orig.tar.gz: freemedforms-0.9.0/libs/utils/idatabasedumper.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2013 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *  Main developer: Eric MAEKER, <eric.maeker@gmail.com>                   *
 *  Contributors:                                                          *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef IDATABASEDUMPER_H
#define IDATABASEDUMPER_H

#include <QObject>

/**
 * \file idatabasedumper.h
 * \author Eric MAEKER <eric.maeker@gmail.com>
 * \version 0.6.0
 * \date 27 Sept 2011
*/

namespace Utils {

class IDatabaseDumper : public QObject
{
    Q_OBJECT
public:
    IDatabaseDumper(QObject *parent = 0) : QObject(parent) {}
    virtual ~IDatabaseDumper() {}

    virtual bool dumpDatabaseToFile(const QString &file, bool zip = true) = 0;
    virtual bool restoreDatabaseFromFile(const QString &file) = 0;

    virtual bool errorEncountered() const = 0;

Q_SIGNALS:
    void processStarted();
    void processDone();
    void error(const QString &error);
    void message(const QString &message);
};

}  // End namespace Utils

#endif // IDATABASEDUMPER_H
